@@ -21,7 +21,6 @@
 #
 
 from datetime import date, datetime
-from json import JSONEncoder as json_JSONEncoder
 from math import isnan, isinf
 from uuid import UUID
 
@@ -29,46 +28,6 @@ from .compat import basestring_, iteritems, long_
 from .util import TZLOCAL, parse_iso8601_date, parse_iso8601_datetime
 
 
-class JSONEncoder(json_JSONEncoder):
-    """
-    JSON encoder class with support for encoding date, datetime, and UUID.
-    """
-
-    def default(self, obj): # pylint: disable=method-hidden
-        if isinstance(obj, date):
-            return obj.isoformat()
-        elif isinstance(obj, datetime):
-            return (obj if obj.tzinfo else obj.replace(tzinfo=TZLOCAL)).isoformat()
-        elif isinstance(obj, UUID):
-            return str(obj)
-        return json_JSONEncoder.default(self, obj)
-
-
-class JSONFloat(float):
-    """
-    Floating point number with precision for JSON encoding.
-    """
-
-    __slots__ = ('json',)
-
-    def __new__(cls, value, dummy_prec=6):
-        return float.__new__(cls, value)
-
-    def __init__(self, value, prec=6):
-        float.__init__(self)
-        if value is not self:
-            self.json = format(value, '.' + str(prec) + 'f').rstrip('0').rstrip('.')
-
-    def __repr__(self):
-        return self.json
-
-    def __str__(self):
-        return self.json
-
-    def __float__(self):
-        return self
-
-
 # Validation mode
 VALIDATE_DEFAULT = 0
 VALIDATE_QUERY_STRING = 1
